@@ -1,8 +1,9 @@
+from collections.abc import Hashable
 from datetime import datetime, timedelta
 import time
 import threading
+from contextlib import suppress  # reexport
 
-from .compat import map, range, raise_from, Hashable
 from .decorators import decorator, wraps, get_argnames, arggetter, contextmanager
 
 
@@ -49,35 +50,6 @@ def silent(func):
     """Alters function to ignore all exceptions."""
     return ignore(Exception)(func)
 
-### Backport of Python 3.4 suppress
-try:
-    from contextlib import suppress
-except ImportError:
-    class suppress(object):
-        """Context manager to suppress specified exceptions
-
-        After the exception is suppressed, execution proceeds with the next
-        statement following the with statement.
-        """
-
-        def __init__(self, *exceptions):
-            self._exceptions = exceptions
-
-        def __enter__(self):
-            pass
-
-        def __exit__(self, exctype, excinst, exctb):
-            # Unlike isinstance and issubclass, CPython exception handling
-            # currently only looks at the concrete type hierarchy (ignoring
-            # the instance and subclass checking hooks). While Guido considers
-            # that a bug rather than a feature, it's a fairly hard one to fix
-            # due to various internal implementation details. suppress provides
-            # the simpler issubclass based semantics, rather than trying to
-            # exactly reproduce the limitations of the CPython interpreter.
-            #
-            # See http://bugs.python.org/issue12029 for more details
-            return exctype is not None and issubclass(exctype, self._exceptions)
-
 
 ### Backport of Python 3.7 nullcontext
 try:
@@ -113,7 +85,7 @@ def reraise(errors, into):
     except errors as e:
         if callable(into) and not _is_exception_type(into):
             into = into(e)
-        raise_from(into, e)
+        raise into from e
 
 
 @decorator
